@@ -12,13 +12,13 @@ __all__ = [
 ]
 
 __title__ = "argo-workflows-dsl"
-__summary__ = "Python DSL for Argo Workflows"
-__uri__ = "https://github.com/argoproj-labs/argo-client-python"
+__summary__ = "DSL for Argo Workflows"
+__uri__ = "https://github.com/CermakM/argo-python-dsl"
 
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 
 __author__ = "Yudi Xue, Marek Cermak"
 __email__ = "binarycrayon@gmail.com, macermak@redhat.com"
 
 __license__ = "Apache Software License"
-__copyright__ = "Copyright 2020 {0}".format(__author__)
+__copyright__ = "Copyright 2019 {0}".format(__author__)
