@@ -4,13 +4,14 @@ __all__ = [
     # modules
     "task",
     "templates",
-
     # decorators
     "tasks",
     "template",
-
     # main
-    "Workflow"
+    "ClusterWorkflowTemplate",
+    "CronWorkflow",
+    "Workflow",
+    "WorkflowTemplate",
 ]
 
 # modules
@@ -22,4 +23,7 @@ from .tasks import task
 from .templates import template
 
 # main
+from ._workflow_template import ClusterWorkflowTemplate
+from ._cronworkflow import CronWorkflow
 from ._workflow import Workflow
+from ._workflow_template import WorkflowTemplate
